import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { IoTEventsDataServiceException as __BaseException } from "./IoTEventsDataServiceException";

export interface AcknowledgeActionConfiguration {
    
    note?: string;
}
export declare namespace AcknowledgeActionConfiguration {
    
    const filterSensitiveLog: (obj: AcknowledgeActionConfiguration) => any;
}

export interface AcknowledgeAlarmActionRequest {
    
    requestId: string | undefined;
    
    alarmModelName: string | undefined;
    
    keyValue?: string;
    
    note?: string;
}
export declare namespace AcknowledgeAlarmActionRequest {
    
    const filterSensitiveLog: (obj: AcknowledgeAlarmActionRequest) => any;
}
export declare enum CustomerActionName {
    ACKNOWLEDGE = "ACKNOWLEDGE",
    DISABLE = "DISABLE",
    ENABLE = "ENABLE",
    RESET = "RESET",
    SNOOZE = "SNOOZE"
}

export interface DisableActionConfiguration {
    
    note?: string;
}
export declare namespace DisableActionConfiguration {
    
    const filterSensitiveLog: (obj: DisableActionConfiguration) => any;
}

export interface EnableActionConfiguration {
    
    note?: string;
}
export declare namespace EnableActionConfiguration {
    
    const filterSensitiveLog: (obj: EnableActionConfiguration) => any;
}

export interface ResetActionConfiguration {
    
    note?: string;
}
export declare namespace ResetActionConfiguration {
    
    const filterSensitiveLog: (obj: ResetActionConfiguration) => any;
}

export interface SnoozeActionConfiguration {
    
    snoozeDuration?: number;
    
    note?: string;
}
export declare namespace SnoozeActionConfiguration {
    
    const filterSensitiveLog: (obj: SnoozeActionConfiguration) => any;
}

export interface CustomerAction {
    
    actionName?: CustomerActionName | string;
    
    snoozeActionConfiguration?: SnoozeActionConfiguration;
    
    enableActionConfiguration?: EnableActionConfiguration;
    
    disableActionConfiguration?: DisableActionConfiguration;
    
    acknowledgeActionConfiguration?: AcknowledgeActionConfiguration;
    
    resetActionConfiguration?: ResetActionConfiguration;
}
export declare namespace CustomerAction {
    
    const filterSensitiveLog: (obj: CustomerAction) => any;
}
export declare enum ComparisonOperator {
    EQUAL = "EQUAL",
    GREATER = "GREATER",
    GREATER_OR_EQUAL = "GREATER_OR_EQUAL",
    LESS = "LESS",
    LESS_OR_EQUAL = "LESS_OR_EQUAL",
    NOT_EQUAL = "NOT_EQUAL"
}

export interface SimpleRuleEvaluation {
    
    inputPropertyValue?: string;
    
    operator?: ComparisonOperator | string;
    
    thresholdValue?: string;
}
export declare namespace SimpleRuleEvaluation {
    
    const filterSensitiveLog: (obj: SimpleRuleEvaluation) => any;
}

export interface RuleEvaluation {
    
    simpleRuleEvaluation?: SimpleRuleEvaluation;
}
export declare namespace RuleEvaluation {
    
    const filterSensitiveLog: (obj: RuleEvaluation) => any;
}
export declare enum AlarmStateName {
    ACKNOWLEDGED = "ACKNOWLEDGED",
    ACTIVE = "ACTIVE",
    DISABLED = "DISABLED",
    LATCHED = "LATCHED",
    NORMAL = "NORMAL",
    SNOOZE_DISABLED = "SNOOZE_DISABLED"
}
export declare enum EventType {
    STATE_CHANGE = "STATE_CHANGE"
}
export declare enum TriggerType {
    SNOOZE_TIMEOUT = "SNOOZE_TIMEOUT"
}

export interface StateChangeConfiguration {
    
    triggerType?: TriggerType | string;
}
export declare namespace StateChangeConfiguration {
    
    const filterSensitiveLog: (obj: StateChangeConfiguration) => any;
}

export interface SystemEvent {
    
    eventType?: EventType | string;
    
    stateChangeConfiguration?: StateChangeConfiguration;
}
export declare namespace SystemEvent {
    
    const filterSensitiveLog: (obj: SystemEvent) => any;
}

export interface AlarmState {
    
    stateName?: AlarmStateName | string;
    
    ruleEvaluation?: RuleEvaluation;
    
    customerAction?: CustomerAction;
    
    systemEvent?: SystemEvent;
}
export declare namespace AlarmState {
    
    const filterSensitiveLog: (obj: AlarmState) => any;
}

export interface Alarm {
    
    alarmModelName?: string;
    
    alarmModelVersion?: string;
    
    keyValue?: string;
    
    alarmState?: AlarmState;
    
    severity?: number;
    
    creationTime?: Date;
    
    lastUpdateTime?: Date;
}
export declare namespace Alarm {
    
    const filterSensitiveLog: (obj: Alarm) => any;
}

export interface AlarmSummary {
    
    alarmModelName?: string;
    
    alarmModelVersion?: string;
    
    keyValue?: string;
    
    stateName?: AlarmStateName | string;
    
    creationTime?: Date;
    
    lastUpdateTime?: Date;
}
export declare namespace AlarmSummary {
    
    const filterSensitiveLog: (obj: AlarmSummary) => any;
}
export interface BatchAcknowledgeAlarmRequest {
    
    acknowledgeActionRequests: AcknowledgeAlarmActionRequest[] | undefined;
}
export declare namespace BatchAcknowledgeAlarmRequest {
    
    const filterSensitiveLog: (obj: BatchAcknowledgeAlarmRequest) => any;
}
export declare enum ErrorCode {
    InternalFailureException = "InternalFailureException",
    InvalidRequestException = "InvalidRequestException",
    ResourceNotFoundException = "ResourceNotFoundException",
    ServiceUnavailableException = "ServiceUnavailableException",
    ThrottlingException = "ThrottlingException"
}

export interface BatchAlarmActionErrorEntry {
    
    requestId?: string;
    
    errorCode?: ErrorCode | string;
    
    errorMessage?: string;
}
export declare namespace BatchAlarmActionErrorEntry {
    
    const filterSensitiveLog: (obj: BatchAlarmActionErrorEntry) => any;
}
export interface BatchAcknowledgeAlarmResponse {
    
    errorEntries?: BatchAlarmActionErrorEntry[];
}
export declare namespace BatchAcknowledgeAlarmResponse {
    
    const filterSensitiveLog: (obj: BatchAcknowledgeAlarmResponse) => any;
}

export declare class InternalFailureException extends __BaseException {
    readonly name: "InternalFailureException";
    readonly $fault: "server";
    
    constructor(opts: __ExceptionOptionType<InternalFailureException, __BaseException>);
}

export declare class InvalidRequestException extends __BaseException {
    readonly name: "InvalidRequestException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<InvalidRequestException, __BaseException>);
}

export declare class ServiceUnavailableException extends __BaseException {
    readonly name: "ServiceUnavailableException";
    readonly $fault: "server";
    
    constructor(opts: __ExceptionOptionType<ServiceUnavailableException, __BaseException>);
}

export declare class ThrottlingException extends __BaseException {
    readonly name: "ThrottlingException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ThrottlingException, __BaseException>);
}

export interface DisableAlarmActionRequest {
    
    requestId: string | undefined;
    
    alarmModelName: string | undefined;
    
    keyValue?: string;
    
    note?: string;
}
export declare namespace DisableAlarmActionRequest {
    
    const filterSensitiveLog: (obj: DisableAlarmActionRequest) => any;
}
export interface BatchDisableAlarmRequest {
    
    disableActionRequests: DisableAlarmActionRequest[] | undefined;
}
export declare namespace BatchDisableAlarmRequest {
    
    const filterSensitiveLog: (obj: BatchDisableAlarmRequest) => any;
}
export interface BatchDisableAlarmResponse {
    
    errorEntries?: BatchAlarmActionErrorEntry[];
}
export declare namespace BatchDisableAlarmResponse {
    
    const filterSensitiveLog: (obj: BatchDisableAlarmResponse) => any;
}

export interface EnableAlarmActionRequest {
    
    requestId: string | undefined;
    
    alarmModelName: string | undefined;
    
    keyValue?: string;
    
    note?: string;
}
export declare namespace EnableAlarmActionRequest {
    
    const filterSensitiveLog: (obj: EnableAlarmActionRequest) => any;
}
export interface BatchEnableAlarmRequest {
    
    enableActionRequests: EnableAlarmActionRequest[] | undefined;
}
export declare namespace BatchEnableAlarmRequest {
    
    const filterSensitiveLog: (obj: BatchEnableAlarmRequest) => any;
}
export interface BatchEnableAlarmResponse {
    
    errorEntries?: BatchAlarmActionErrorEntry[];
}
export declare namespace BatchEnableAlarmResponse {
    
    const filterSensitiveLog: (obj: BatchEnableAlarmResponse) => any;
}

export interface TimestampValue {
    
    timeInMillis?: number;
}
export declare namespace TimestampValue {
    
    const filterSensitiveLog: (obj: TimestampValue) => any;
}

export interface Message {
    
    messageId: string | undefined;
    
    inputName: string | undefined;
    
    payload: Uint8Array | undefined;
    
    timestamp?: TimestampValue;
}
export declare namespace Message {
    
    const filterSensitiveLog: (obj: Message) => any;
}
export interface BatchPutMessageRequest {
    
    messages: Message[] | undefined;
}
export declare namespace BatchPutMessageRequest {
    
    const filterSensitiveLog: (obj: BatchPutMessageRequest) => any;
}

export interface BatchPutMessageErrorEntry {
    
    messageId?: string;
    
    errorCode?: ErrorCode | string;
    
    errorMessage?: string;
}
export declare namespace BatchPutMessageErrorEntry {
    
    const filterSensitiveLog: (obj: BatchPutMessageErrorEntry) => any;
}
export interface BatchPutMessageResponse {
    
    BatchPutMessageErrorEntries?: BatchPutMessageErrorEntry[];
}
export declare namespace BatchPutMessageResponse {
    
    const filterSensitiveLog: (obj: BatchPutMessageResponse) => any;
}

export interface ResetAlarmActionRequest {
    
    requestId: string | undefined;
    
    alarmModelName: string | undefined;
    
    keyValue?: string;
    
    note?: string;
}
export declare namespace ResetAlarmActionRequest {
    
    const filterSensitiveLog: (obj: ResetAlarmActionRequest) => any;
}
export interface BatchResetAlarmRequest {
    
    resetActionRequests: ResetAlarmActionRequest[] | undefined;
}
export declare namespace BatchResetAlarmRequest {
    
    const filterSensitiveLog: (obj: BatchResetAlarmRequest) => any;
}
export interface BatchResetAlarmResponse {
    
    errorEntries?: BatchAlarmActionErrorEntry[];
}
export declare namespace BatchResetAlarmResponse {
    
    const filterSensitiveLog: (obj: BatchResetAlarmResponse) => any;
}

export interface SnoozeAlarmActionRequest {
    
    requestId: string | undefined;
    
    alarmModelName: string | undefined;
    
    keyValue?: string;
    
    note?: string;
    
    snoozeDuration: number | undefined;
}
export declare namespace SnoozeAlarmActionRequest {
    
    const filterSensitiveLog: (obj: SnoozeAlarmActionRequest) => any;
}
export interface BatchSnoozeAlarmRequest {
    
    snoozeActionRequests: SnoozeAlarmActionRequest[] | undefined;
}
export declare namespace BatchSnoozeAlarmRequest {
    
    const filterSensitiveLog: (obj: BatchSnoozeAlarmRequest) => any;
}
export interface BatchSnoozeAlarmResponse {
    
    errorEntries?: BatchAlarmActionErrorEntry[];
}
export declare namespace BatchSnoozeAlarmResponse {
    
    const filterSensitiveLog: (obj: BatchSnoozeAlarmResponse) => any;
}

export interface TimerDefinition {
    
    name: string | undefined;
    
    seconds: number | undefined;
}
export declare namespace TimerDefinition {
    
    const filterSensitiveLog: (obj: TimerDefinition) => any;
}

export interface VariableDefinition {
    
    name: string | undefined;
    
    value: string | undefined;
}
export declare namespace VariableDefinition {
    
    const filterSensitiveLog: (obj: VariableDefinition) => any;
}

export interface DetectorStateDefinition {
    
    stateName: string | undefined;
    
    variables: VariableDefinition[] | undefined;
    
    timers: TimerDefinition[] | undefined;
}
export declare namespace DetectorStateDefinition {
    
    const filterSensitiveLog: (obj: DetectorStateDefinition) => any;
}

export interface UpdateDetectorRequest {
    
    messageId: string | undefined;
    
    detectorModelName: string | undefined;
    
    keyValue?: string;
    
    state: DetectorStateDefinition | undefined;
}
export declare namespace UpdateDetectorRequest {
    
    const filterSensitiveLog: (obj: UpdateDetectorRequest) => any;
}
export interface BatchUpdateDetectorRequest {
    
    detectors: UpdateDetectorRequest[] | undefined;
}
export declare namespace BatchUpdateDetectorRequest {
    
    const filterSensitiveLog: (obj: BatchUpdateDetectorRequest) => any;
}

export interface BatchUpdateDetectorErrorEntry {
    
    messageId?: string;
    
    errorCode?: ErrorCode | string;
    
    errorMessage?: string;
}
export declare namespace BatchUpdateDetectorErrorEntry {
    
    const filterSensitiveLog: (obj: BatchUpdateDetectorErrorEntry) => any;
}
export interface BatchUpdateDetectorResponse {
    
    batchUpdateDetectorErrorEntries?: BatchUpdateDetectorErrorEntry[];
}
export declare namespace BatchUpdateDetectorResponse {
    
    const filterSensitiveLog: (obj: BatchUpdateDetectorResponse) => any;
}
export interface DescribeAlarmRequest {
    
    alarmModelName: string | undefined;
    
    keyValue?: string;
}
export declare namespace DescribeAlarmRequest {
    
    const filterSensitiveLog: (obj: DescribeAlarmRequest) => any;
}
export interface DescribeAlarmResponse {
    
    alarm?: Alarm;
}
export declare namespace DescribeAlarmResponse {
    
    const filterSensitiveLog: (obj: DescribeAlarmResponse) => any;
}

export declare class ResourceNotFoundException extends __BaseException {
    readonly name: "ResourceNotFoundException";
    readonly $fault: "client";
    
    constructor(opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>);
}
export interface DescribeDetectorRequest {
    
    detectorModelName: string | undefined;
    
    keyValue?: string;
}
export declare namespace DescribeDetectorRequest {
    
    const filterSensitiveLog: (obj: DescribeDetectorRequest) => any;
}

export interface Timer {
    
    name: string | undefined;
    
    timestamp: Date | undefined;
}
export declare namespace Timer {
    
    const filterSensitiveLog: (obj: Timer) => any;
}

export interface Variable {
    
    name: string | undefined;
    
    value: string | undefined;
}
export declare namespace Variable {
    
    const filterSensitiveLog: (obj: Variable) => any;
}

export interface DetectorState {
    
    stateName: string | undefined;
    
    variables: Variable[] | undefined;
    
    timers: Timer[] | undefined;
}
export declare namespace DetectorState {
    
    const filterSensitiveLog: (obj: DetectorState) => any;
}

export interface Detector {
    
    detectorModelName?: string;
    
    keyValue?: string;
    
    detectorModelVersion?: string;
    
    state?: DetectorState;
    
    creationTime?: Date;
    
    lastUpdateTime?: Date;
}
export declare namespace Detector {
    
    const filterSensitiveLog: (obj: Detector) => any;
}
export interface DescribeDetectorResponse {
    
    detector?: Detector;
}
export declare namespace DescribeDetectorResponse {
    
    const filterSensitiveLog: (obj: DescribeDetectorResponse) => any;
}

export interface DetectorStateSummary {
    
    stateName?: string;
}
export declare namespace DetectorStateSummary {
    
    const filterSensitiveLog: (obj: DetectorStateSummary) => any;
}

export interface DetectorSummary {
    
    detectorModelName?: string;
    
    keyValue?: string;
    
    detectorModelVersion?: string;
    
    state?: DetectorStateSummary;
    
    creationTime?: Date;
    
    lastUpdateTime?: Date;
}
export declare namespace DetectorSummary {
    
    const filterSensitiveLog: (obj: DetectorSummary) => any;
}
export interface ListAlarmsRequest {
    
    alarmModelName: string | undefined;
    
    nextToken?: string;
    
    maxResults?: number;
}
export declare namespace ListAlarmsRequest {
    
    const filterSensitiveLog: (obj: ListAlarmsRequest) => any;
}
export interface ListAlarmsResponse {
    
    alarmSummaries?: AlarmSummary[];
    
    nextToken?: string;
}
export declare namespace ListAlarmsResponse {
    
    const filterSensitiveLog: (obj: ListAlarmsResponse) => any;
}
export interface ListDetectorsRequest {
    
    detectorModelName: string | undefined;
    
    stateName?: string;
    
    nextToken?: string;
    
    maxResults?: number;
}
export declare namespace ListDetectorsRequest {
    
    const filterSensitiveLog: (obj: ListDetectorsRequest) => any;
}
export interface ListDetectorsResponse {
    
    detectorSummaries?: DetectorSummary[];
    
    nextToken?: string;
}
export declare namespace ListDetectorsResponse {
    
    const filterSensitiveLog: (obj: ListDetectorsResponse) => any;
}
